/********************************
	i8093 Error Code definition	
*******************************/

#define OK 		 				       0	
#define ID_ERROR 				    -1
#define SLOT_OUT_RANGE			-2
#define CHANNEL_OUT_RANGE		-3
#define MODE_ERROR				  -4
#define FIRMWARENOTSUPPORT  -5

	
#ifdef	__cplusplus  // for C++ compile use
extern "C" {
#endif	/*	__cplusplus	*/

/********************************
	return Lattice version	
*******************************/
short i8093W_GetFirmwareVersion(int slot);


/********************************
	i8093W_GetLibVersion can get the version i8093W Lib
	return Lib version	
*******************************/
short i8093W_GetLibVersion(void);
          
          
/********************************
	i8093W_GetLibDate can get the builded date of i8093W Lib
	1.*LibDate: library date	
*******************************/  
//void i8093W_GetLibDate(char *LibDate);


/********************************
	i8093W_Init can initialize i-8093W
	return value: please refer to i8093W Error Code definition		
*******************************/
int i8093W_Init(int slot);


/********************************
	i8093W_SetMode can set encoder counting mode
	1. slot: 1 ~ 8
	2. ch: 0 ~ 2
	3. Mode value:
	   1 ==> CW/CCW counting mode
	   2 ==> Pulse/Direction counting mode
	   3 ==> Quadrant counting mode
	return value: please refer to i8093W Error Code definition
*******************************/
 
int i8093W_SetMode(int slot, int ch, int Mode);


/********************************
	i8093W_GetMode can get encoder counting mode
	1. slot: 1 ~ 8
	2. ch: 0 ~ 2
	3. *Mode value:
	   *Mode=1 ==> CW/CCW counting mode
	   *Mode=2 ==> Pulse/Direction counting mode
	   *Mode=3 ==> Quadrant counting mode

	return value: please refer to i8093W Error Code definition
*******************************/
 
int i8093W_GetMode(int slot, int ch, int* Mode);


/********************************
	i8093W_GetLineStatus can read A/B/Z status
	1. slot: 1 ~ 8
	2. ch: 0 ~ 2
	3. *A_Status: 0/1
	4. *B_Status: 0/1
  5. *C_Status: 0/1 
  	
	return value: please refer to i8093W Error Code definition
*******************************/
 
int i8093W_GetLineStatus(int slot, int ch, int* A_Status,int* B_Status,int* C_Status);


/********************************
	i8093W_GetIndex can read Index(Z) value
	1. slot: 1 ~ 8
	2. ch: 0 ~ 2
	3. *index: 0/1

	return value: please refer to i8093W Error Code definition	
*******************************/
 
int i8093W_GetIndex(int slot, int ch,int* index);


/********************************
	i8093W_SetXOR can set XOR value 
	1. slot: 1 ~ 8
	2. ch: 0 ~ 2
	3. Xor: 0/1
	
	return value: please refer to i8093W Error Code definition
*******************************/
int i8093W_SetXOR(int slot, int ch, int Xor);


/********************************
	i8093W_GetXOR can get XOR value
	1. slot: 1 ~ 8
	2. ch: 0 ~ 2
	3. *Xor: 0/1
	
	return value: please refer to i8093W Error Code definition
*******************************/
 
int i8093W_GetXOR(int slot, int ch, int* Xor);


/********************************
	i8093W_Read32BitEncoder can read 32-bit counter value
	1. slot: 1 ~ 8
	2. ch: 0 ~ 2
	3. *EnCode32: 32-bit counter value
	
	return value: return Index enable/disable and Index latched status
	0: Disable Index Latch (0), Index Not Latched (0)
	1: Enable Index Latch  (1), Index Not Latched (0)
	2: Disable Index Latch (0), Index Latched (1)
	3: Enable Index Latch  (1), Index Latched (1)
*******************************/
 
int i8093W_Read32BitEncoder(int slot,int ch, long* EnCode32);


/********************************
	i8093W_ResetEncoder can clear A/B/Z and 32 bit counter
	1. slot 1 ~ 8
	2. ch 0 ~ 2
*******************************/ 
int i8093W_ResetEncoder(int slot, int ch);

/********************************
 i8093W_SetPresetValue can set the preset value of i-8093W
 1. slot 1 ~ 8 
 2. ch 0 ~ 2 
 3. PresetVal 0 ~ 0xffffffff
 return value: please refer to i8093WW Error Code definition 
 Note1: preset value is supported at lib version 0x1007 or above 
*******************************/ 
int i8093W_SetPresetValue(int slot, int ch, long presetVal);


/********************************
 i8093W_GetPresetValue can get the preset value of i-8093W
 1. slot 1 ~ 8 
 2. ch 0 ~ 2 
 3. PresetVal 0 ~ 0xffffffff
 return value: please refer to i8093WW Error Code definition 
 Note1: preset value is supported at lib version 0x1007 or above 
*******************************/ 
int i8093W_GetPresetValue(int slot, int ch, long* presetVal);


/********************************
 i8093W_SetPresetValue can set the preset value of i-8093W
 1. slot 1 ~ 8 
 2. ch 0 ~ 2 
 3. PresetVal 0 ~ 0xffffffff
 return value: please refer to i8093WW Error Code definition 
 Note1: preset value is supported at lib version 0x1007 or above 
*******************************/ 
int i8093W_SetLowPassFilter(int slot, int ch, int filter);


/********************************
 i8093W_GetPresetValue can get the preset value of i-8093W
 1. slot 1 ~ 8 
 2. ch 0 ~ 2 
 3. PresetVal 0 ~ 0xffffffff
 return value: please refer to i8093WW Error Code definition 
 Note1: preset value is supported at lib version 0x1007 or above 
*******************************/ 
int i8093W_GetLowPassFilter(int slot, int ch, int* filter);



// compared trigger function
/*
int i8093W_ReadLatchedPosition(int slot,int ch,long* Data32);
int i8093W_ReadNextPosition(int slot,int ch,long* Data32);
int i8093W_ClearNextPosition(int slot,int ch);

int i8093W_SetExTrigMode(int slot, int ch, unsigned char Mode);
int i8093W_GetExTrigMode(int slot, int ch, unsigned char *Mode);

int i8093W_SetExSignal(int slot, unsigned char Edge);
int i8093W_GetExSignal(int slot, unsigned char *Edge);
int i8093W_SetFirstTrigPosition(int slot, int ch, long Position);
int i8093W_GetFirstTrigPosition(int slot, int ch, long* Position);
int i8093W_SetTrigDistance(int slot, int ch, long Distance);
int i8093W_GetTrigDistance(int slot, int ch, long* Distance);
int i8093W_SetPreTriggerSteps(int slot,int ch, unsigned char Steps);
int i8093W_GetPreTriggerSteps(int slot, int ch, unsigned char *Steps);
int i8093W_ConfigTriggerOut(int slot,int ch, unsigned char enStatus);
int i8093W_GetTriggerOutConfig(int slot, int ch, unsigned char *enStatus);
*/

#ifdef	__cplusplus
}
#endif	/*	__cplusplus	*/
