﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using I8120net_PAC;

namespace RecMsg
{
    public partial class Form1 : Form
    {
        int MAX_LINE = 1000;
        byte Slot;
        byte Baud;
        byte TimerEnable;
        int LineCnt;
        string StrText="";
        static Object ThisLock = new Object(); //This is used to avoid mulit-accessing the same I-8120W
        //in the different functions or threads simultaneously. It is useless 
        //while the functions or threads access the I-8120W with different slot.

        public Form1()
        {
            InitializeComponent();
        }

        private void Btn_Clear_Click(object sender, EventArgs e)
        {
            List_Msg.Items.Clear();
            LineCnt = 0;
        }

        private void Btn_Pause_Click(object sender, EventArgs e)
        {
             if (TimerEnable == 1){
                TimerEnable = 0;
                timer1.Enabled = false;
                Btn_Pause.Text = "Go";
             }
            else{
                TimerEnable = 1;
                timer1.Enabled = true;
                Btn_Pause.Text = "Pause";
             }
        }

        private void Btn_Init_Click(object sender, EventArgs e)
        {
            int Ret;

            lock (ThisLock)
            {
                //This is used to avoid mulit-accessing the same I-8120W
                //in the different functions or threads simultaneously. It is useless 
                //while the functions or threads access the I-8120W with different slot.
                Ret = I8120.I8120_Init(Slot);
            }
            if (Ret != 0)
            {
                StrText = String.Format("I-8120 Init Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                return;
            }

            lock (ThisLock)
            {
                Ret = I8120.I8120_HardwareReset(Slot);
            }
            if (Ret != 0)
            {
                StrText = String.Format("I-8120 HardwareReset Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                return;
            }

            lock (ThisLock)
            {
                Ret = I8120.I8120_ConfigWithoutStruct(Slot, 0, Convert.ToUInt32(0xFFFFFFFF), Baud, 0, 0);
            }
            if (Ret != 0)
            {
                StrText = String.Format("I-8120 Config Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                return;
            }

            Btn_Init.Enabled = false;

            Btn_Pause.Enabled = true;
            Btn_Clear.Enabled = true;

            timer1.Enabled = true;
            TimerEnable = 1;
            LineCnt = 0;
        }

        private void Combo_Baud_SelectedIndexChanged(object sender, EventArgs e)
        {
            Baud = Convert.ToByte(Combo_Baud.SelectedIndex + 1);
        }

        private void Combo_Slot_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (Slot != Convert.ToByte(Combo_Slot.SelectedIndex))
            {
                lock (ThisLock)
                {
                    I8120.I8120_RestoreI8120(Slot);
                }
                timer1.Enabled = false;
                Slot = Convert.ToByte(Combo_Slot.SelectedIndex);
                Btn_Init.Enabled = true;

                Btn_Pause.Enabled = false;
                Btn_Clear.Enabled = false;
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            Btn_Init.Enabled = true;

            Btn_Pause.Enabled = false;
            Btn_Clear.Enabled = false;

            Combo_Slot.SelectedIndex = 0;
            Combo_Baud.SelectedIndex = 7;

            Slot = 0;
            Baud = 8;
        }

        private void Form1_Closed(object sender, EventArgs e)
        {
            lock (ThisLock)
            {
                I8120.I8120_RestoreI8120(Slot);
            }
            timer1.Enabled = false;
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            byte TempCANReg, TempOverflowFlag=0;
            byte Mode, RTR, DataLen;
            byte [] Data = new byte[8]; 
            ushort MsgCnt;
            int Ret, i, j;
            uint  ID, UpperTimeStamp, LowerTimeStamp;
            Int64 TimeStamp;
            string Str_Data="", Str_ID="";

            //Get I-8120W status from I-8120W module
            lock (ThisLock)
            {
                Ret = I8120.I8120_Status(Slot, out TempCANReg);
            }
            if (Ret != 0)
            {
                timer1.Enabled = false;
                TimerEnable = 0;
                StrText = String.Format("Get Status Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                return;
            }

            //Get CAN message from I-8120W
            lock (ThisLock)
            {
                Ret = I8120.I8120_RxMsgCount(Slot, out MsgCnt);
            }
            if (Ret != 0)
            {
                timer1.Enabled = false;
                TimerEnable = 0;
                StrText = String.Format("Get Message count Err = {0:D}", Ret);
                MessageBox.Show(StrText);
            }

            if (MsgCnt != 0)
            {
                for (i = 0; i < MsgCnt; i++)
                {
                    lock (ThisLock)
                    {
                        Ret = I8120.I8120_ReceiveWithoutStruct(Slot, out Mode, out ID, out RTR, out DataLen, Data, out UpperTimeStamp, out LowerTimeStamp);
                    }
                    {
                        if (Ret != 0)
                        {
                            if (Ret == 22) // I8120_SoftBufferIsFull           
                            {
                                TempOverflowFlag |= 0x01;
                            }
                            else
                            {
                                timer1.Enabled = false;
                                TimerEnable = 0;
                                StrText = String.Format("Get Message count Err = {0:D}", Ret);
                                MessageBox.Show(StrText);
                            }
                        }
                        else    //Show the receive CAN message information in the list control object
                        {
                            TempOverflowFlag &= 0xFE;
                            TimeStamp = UpperTimeStamp;
                            TimeStamp = (TimeStamp << 32);
                            TimeStamp = TimeStamp + LowerTimeStamp;

                            if (RTR != 0)
                            {
                                if (Mode != 0)
                                {
                                    Str_ID = LineCnt.ToString("D3") + " 2.0B " + ID.ToString("X8") + " Y " + DataLen.ToString() + TimeStamp.ToString();
                                    List_Msg.Items.Add(Str_ID);
                                }
                                else
                                {
                                    Str_ID = LineCnt.ToString("D3") + " 2.0A         " + ID.ToString("X3") + " Y " + DataLen.ToString() + TimeStamp.ToString();
                                    List_Msg.Items.Add(Str_ID);
                                }
                            }
                            else
                            {
                                Str_Data = "";
                                for(j=0;j<DataLen;j++)
                                {
                                    Str_Data = Str_Data + " " + Data[j].ToString("X2");
                                }
                                
                                if (Mode != 0)
                                {
                                    Str_ID = LineCnt.ToString("D3") + " 2.0B " + ID.ToString("X8") + " N " + DataLen.ToString() + Str_Data + " " + TimeStamp.ToString();
                                    List_Msg.Items.Add(Str_ID);
                                }
                                else
                                {
                                    Str_ID = LineCnt.ToString("D3") + " 2.0A         " + ID.ToString("X3") + " N " + DataLen.ToString() + Str_Data + " " + TimeStamp.ToString();
                                    List_Msg.Items.Add(Str_ID);
                                }
                            }
                            List_Msg.SelectedIndex = LineCnt;
                            LineCnt = LineCnt + 1;
                        }

                        if (LineCnt == MAX_LINE){
                            List_Msg.Items.Clear();
                            LineCnt = 0;
                        }
                    }
                }
            }

            Lab_Status.Text = "0x" + TempCANReg.ToString("X2");
            Lab_Overflow.Text = "0x" + TempOverflowFlag.ToString("X2");
        }
    }
}