﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using I8120net_PAC;

namespace SendMsg
{
    public partial class Form1 : Form
    {
        byte Slot;
        byte Baud;
        byte t_Rtr;
        byte t_Mode;
        string StrText = "";
        static Object ThisLock = new Object(); //This is used to avoid mulit-accessing the same I-8120W
        //in the different functions or threads simultaneously. It is useless 
        //while the functions or threads access the I-8120W with different slot.

        public Form1()
        {
            InitializeComponent();
        }

        private void Btn_Send_Click(object sender, EventArgs e)
        {
            int Ret;
            uint t_ID;
            byte t_Dlen;
            byte [] t_Data = new byte[8];


            t_ID = Convert.ToUInt32(Text_ID.Text,16);
            t_Dlen = Convert.ToByte(Text_Len.Text);
            t_Data[0] = Convert.ToByte(Text_Data.Text.Substring(0, 2),16);
            t_Data[1] = Convert.ToByte(Text_Data.Text.Substring(3, 2),16);
            t_Data[2] = Convert.ToByte(Text_Data.Text.Substring(6, 2),16);
            t_Data[3] = Convert.ToByte(Text_Data.Text.Substring(9, 2),16);
            t_Data[4] = Convert.ToByte(Text_Data.Text.Substring(12, 2),16);
            t_Data[5] = Convert.ToByte(Text_Data.Text.Substring(15, 2),16);
            t_Data[6] = Convert.ToByte(Text_Data.Text.Substring(18, 2),16);
            t_Data[7] = Convert.ToByte(Text_Data.Text.Substring(21, 2),16);

            lock (ThisLock)
            {
                //This is used to avoid mulit-accessing the same I-8120W
                //in the different functions or threads simultaneously. It is useless 
                //while the functions or threads access the I-8120W with different slot.
                Ret = I8120.I8120_SendWithoutStruct(Slot, t_Mode, t_ID, t_Rtr, t_Dlen, t_Data);
            }
            if (Ret != 0){
                StrText = String.Format("I-8120 Send Message Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                return;
            }
        }

        private void Text_ID_TextChanged(object sender, EventArgs e)
        {
            if (t_Mode == 1){
                if (Convert.ToUInt32(Text_ID.Text,16)> 0x1FFFFFFF){
                    Text_ID.Text = "1FFFFFFF";
                }
            }
            else{
                if (Convert.ToUInt32(Text_ID.Text,16) > 0x7FF){
                    Text_ID.Text = "7FF";
                }
            }
        }

        private void Text_Len_TextChanged(object sender, EventArgs e)
        {
            if (Convert.ToByte(Text_Len.Text) > 8)
            {
                Text_ID.Text = "8";
            }
        }

        private void Check_RTR_CheckStateChanged(object sender, EventArgs e)
        {
            if (Check_RTR.Checked == true) {
                t_Rtr = 1;
            }
            else{
                t_Rtr = 0;
            }
        }

        private void ID_Bit29_CheckedChanged(object sender, EventArgs e)
        {
            if (ID_Bit29.Checked == true)
            {
                ID_Bit11.Checked = false;
                t_Mode = 1;
                Text_ID.MaxLength = 8;
                Text_ID.Text = "1FFFFFFF";
            }
        }

        private void ID_Bit11_CheckedChanged(object sender, EventArgs e)
        {
            if (ID_Bit11.Checked == true){
                ID_Bit29.Checked = false;
                t_Mode = 0;
                Text_ID.MaxLength = 3;
                Text_ID.Text = "7FF";
            }
        }

        private void Btn_Init_Click(object sender, EventArgs e)
        {
            int Ret;

            lock (ThisLock)
            {
                Ret = I8120.I8120_Init(Slot);
            }
            if (Ret != 0)
            {
                StrText = String.Format("I-8120 Init Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                return;
            }

            lock (ThisLock)
            {
                Ret = I8120.I8120_HardwareReset(Slot);
            }
            if (Ret != 0)
            {
                StrText = String.Format("I-8120 HardwareReset Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                return;
            }

            lock (ThisLock)
            {
                Ret = I8120.I8120_ConfigWithoutStruct(Slot, 0, Convert.ToUInt32(0xFFFFFFFF), Baud, 0, 0);
            }
            if (Ret != 0)
            {
                StrText = String.Format("I-8120 Config Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                return;
            }
            
            Btn_Init.Enabled = false;
            Send_Panel.Enabled = true;
            timer1.Enabled = true;
        }

        private void Combo_Baud_SelectedIndexChanged(object sender, EventArgs e)
        {
            Baud = Convert.ToByte(Combo_Baud.SelectedIndex + 1);
        }

        private void Combo_Slot_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (Slot != Convert.ToByte(Combo_Slot.SelectedIndex))
            {
                lock (ThisLock)
                {
                    I8120.I8120_RestoreI8120(Slot);
                }
                timer1.Enabled = false;
                Slot = Convert.ToByte(Combo_Slot.SelectedIndex);
                Btn_Init.Enabled = true;
                Send_Panel.Enabled = false;
            }

        }

        private void Form1_Load(object sender, EventArgs e)
        {
            Btn_Init.Enabled = true;
            Send_Panel.Enabled = false;

            Combo_Slot.SelectedIndex = 0;
            Combo_Baud.SelectedIndex = 7;

            ID_Bit11.Checked = true;
            ID_Bit29.Checked = false;
            Check_RTR.Checked = false;

            Slot = 0;
            Baud = 8;

            t_Rtr = 0;
            t_Mode = 0;
            Text_Len.MaxLength = 1;
            Text_Len.Text = "8";
            Text_ID.MaxLength = 3;
            Text_ID.Text = "7FF";
            Text_Data.MaxLength = 24;
            Text_Data.Text = "11 22 33 44 55 66 77 88";
        }

        private void Form1_Closed(object sender, EventArgs e)
        {
            lock (ThisLock)
            {
                I8120.I8120_RestoreI8120(Slot);
            }
            timer1.Enabled = false;
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            int Ret;
            byte TxStatus;

            lock (ThisLock)
            {
                Ret = I8120.I8120_IsTxTimeout(Slot, out TxStatus);
            }
            if (Ret != 0){
                StrText = String.Format(StrText, "I-8120 check is Tx Timeout Err = {0:D}", Ret);
                MessageBox.Show(StrText);
                timer1.Enabled = false;
                return;
            }

            if (TxStatus != 0){
                Lab_Send.Text = "Timeout !";
            }
             else{
                Lab_Send.Text = "Send OK";
            }
        }
    }
}